summaryrefslogtreecommitdiffstats
path: root/chrome/browser/about_flags.h
diff options
context:
space:
mode:
authorgavinp@chromium.org <gavinp@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-11 16:15:53 +0000
committergavinp@chromium.org <gavinp@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-11 16:15:53 +0000
commita8274453e82a243b65436b8b3e5c5bff80ab90c7 (patch)
treee8cd421d5a8aeda347d3461bdded67db7104d696 /chrome/browser/about_flags.h
parentac4fbedeefe7f5cae229a545ddc679eaf42351ca (diff)
downloadchromium_src-a8274453e82a243b65436b8b3e5c5bff80ab90c7.zip
chromium_src-a8274453e82a243b65436b8b3e5c5bff80ab90c7.tar.gz
chromium_src-a8274453e82a243b65436b8b3e5c5bff80ab90c7.tar.bz2
Modify about:flags to support switches with values.
about:flags right now doesn't support switches like "--foo=bar". It only handles simple switches like "--quux". The prerender feature has a few options, and to avoid confusing contradictory mixes of simple switches, we want to use valued switches. But for that, we'll need lab support. BUG=none TEST=AboutFlagsTest.* Review URL: http://codereview.chromium.org/6483015 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@74599 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/about_flags.h')
-rw-r--r--chrome/browser/about_flags.h14
1 files changed, 9 insertions, 5 deletions
diff --git a/chrome/browser/about_flags.h b/chrome/browser/about_flags.h
index 1130b8c..780e9fb 100644
--- a/chrome/browser/about_flags.h
+++ b/chrome/browser/about_flags.h
@@ -42,8 +42,10 @@ struct Experiment {
// ID of the message containing the choice name.
int description_id;
- // Command line to enabled for this choice.
- const char* command_line;
+ // Command line switch and value to enabled for this choice.
+ const char* command_line_switch;
+ // Simple switches that have no value should use "" for command_line_value.
+ const char* command_line_value;
};
// The internal name of the experiment. This is never shown to the user.
@@ -64,11 +66,13 @@ struct Experiment {
// Type of experiment.
Type type;
// The commandline parameter that's added when this lab is active. This is
// different from |internal_name| so that the commandline flag can be
// renamed without breaking the prefs file.
// This is used if type is SINGLE_VALUE.
- const char* command_line;
+ const char* command_line_switch;
+ // Simple switches that have no value should use "" for command_line_value.
+ const char* command_line_value;
// This is used if type is MULTI_VALUE.
const Choice* choices;
@@ -64,11 +66,13 @@ struct Experiment {
// Type of experiment.
Type type;
- // The commandline parameter that's added when this lab is active. This is
- // different from |internal_name| so that the commandline flag can be
+ // The commandline switch and value that are added when this lab is active.
+ // This is different from |internal_name| so that the commandline flag can be
// renamed without breaking the prefs file.
// This is used if type is SINGLE_VALUE.